@@ -8,16 +8,16 @@ def checkrs(rs):
     else:
         return True
 
-class Client():
+class client():
     def __init__(self, rosec=None):
         self.User = _User(rosec)
         self.Group = _Group(rosec)
 
-class _User():
+class _user():
     def __init__(self, rosec):
         self._rosec = rosec
     
-    def Check(self, user):
+    def check(self, user):
         isint = True
         try:
             user = int(user)
@@ -37,7 +37,7 @@ class _User():
         else:
             return {"exist": False}
     
-    def Info(self, user):
+    def info(self, user):
         isint = True
         try:
             user = int(user)
@@ -75,7 +75,7 @@ class _User():
         else:
             return "That user doesn't exist"
     
-    def Activity(self, user):
+    def activity(self, user):
         isint = True
         try:
             user = int(user)
@@ -127,7 +127,7 @@ class _User():
         else:
             return el["errors"][0]["message"]
 
-    def Groups(self, user):
+    def groups(self, user):
         isint = True
         try:
             user = int(user)
@@ -156,11 +156,11 @@ class _User():
         else:
             return el["errors"][0]["message"]
 
-class _Group():
+class _group():
     def __init__(self, rosec):
         self._rosec = rosec
     
-    def Info(self, id):
+    def info(self, id):
         el = requests.get(f"https://groups.roblox.com/v1/groups/{id}")
         el = json.loads(el.text)
         foo = requests.get("https://thumbnails.roblox.com/v1/groups/icons", params={"groupIds": id, "size": "420x420", "format": "png"})
@@ -182,7 +182,7 @@ class _Group():
         else:
             return el["errors"][0]["message"]
     
-    def Roles(self, id):
+    def roles(self, id):
         el = requests.get(f"https://groups.roblox.com/v1/groups/{id}/roles")
         el = json.loads(el.text)
         if "errors" not in el:
@@ -197,7 +197,7 @@ class _Group():
         else:
             return el["errors"][0]["message"]
     
-    def Shout(self, id, shout):
+    def shout(self, id, shout):
         rosec = self._rosec
         if rosec:
             rscheck = checkrs(rosec)
@@ -214,7 +214,7 @@ class _Group():
         else:
             return "You don't have a connected roblosecurity"
     
-    def Accept(self, groupid, user):
+    def accept(self, groupid, user):
         rosec = self._rosec
         if rosec:
             rscheck = checkrs(rosec)
@@ -243,7 +243,7 @@ class _Group():
         else:
             return "You don't have a connected roblosecurity"
 
-    def AcceptAll(self, groupid):
+    def acceptall(self, groupid):
         rosec = self._rosec
         if rosec:
             rscheck = checkrs(rosec)
@@ -278,7 +278,7 @@ class _Group():
         else:
             return "You don't have a connected roblosecurity"
 
-    def DeclineAll(self, groupid):
+    def declineall(self, groupid):
         rosec = self._rosec
         if rosec:
             rscheck = checkrs(rosec)
@@ -313,7 +313,7 @@ class _Group():
         else:
             return "You don't have a connected roblosecurity"
     
-    def Rank(self, groupid, user, rank):
+    def rank(self, groupid, user, rank):
         rosec = self._rosec
         if rosec:
             rscheck = checkrs(rosec)
@@ -394,7 +394,7 @@ class _Group():
         else:
             return "You don't have a connected roblosecurity"
     
-    def Exile(self, groupid, user):
+    def exile(self, groupid, user):
         rosec = self._rosec
         if rosec:
             rscheck = checkrs(rosec)
